pub struct ActivityGovernorTakeWakeLeaseRequest {
pub name: String,
}Fields
name: StringTrait Implementations
Sourceimpl Clone for ActivityGovernorTakeWakeLeaseRequest
impl Clone for ActivityGovernorTakeWakeLeaseRequest
Sourcefn clone(&self) -> ActivityGovernorTakeWakeLeaseRequest
fn clone(&self) -> ActivityGovernorTakeWakeLeaseRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<ActivityGovernorTakeWakeLeaseRequest<'static>, ___E> for &'a ActivityGovernorTakeWakeLeaseRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<ActivityGovernorTakeWakeLeaseRequest<'static>, ___E> for &'a ActivityGovernorTakeWakeLeaseRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorTakeWakeLeaseRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorTakeWakeLeaseRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ActivityGovernorTakeWakeLeaseRequest<'static>, ___E> for ActivityGovernorTakeWakeLeaseRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<ActivityGovernorTakeWakeLeaseRequest<'static>, ___E> for ActivityGovernorTakeWakeLeaseRequestwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorTakeWakeLeaseRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorTakeWakeLeaseRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ActivityGovernorTakeWakeLeaseRequest<'static>>, ___E> for &'a ActivityGovernorTakeWakeLeaseRequestwhere
___E: Encoder + ?Sized,
&'a ActivityGovernorTakeWakeLeaseRequest: Encode<ActivityGovernorTakeWakeLeaseRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ActivityGovernorTakeWakeLeaseRequest<'static>>, ___E> for &'a ActivityGovernorTakeWakeLeaseRequestwhere
___E: Encoder + ?Sized,
&'a ActivityGovernorTakeWakeLeaseRequest: Encode<ActivityGovernorTakeWakeLeaseRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a ActivityGovernorTakeWakeLeaseRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ActivityGovernorTakeWakeLeaseRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a ActivityGovernorTakeWakeLeaseRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ActivityGovernorTakeWakeLeaseRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ActivityGovernorTakeWakeLeaseRequest<'static>>, ___E> for ActivityGovernorTakeWakeLeaseRequestwhere
___E: Encoder + ?Sized,
ActivityGovernorTakeWakeLeaseRequest: Encode<ActivityGovernorTakeWakeLeaseRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ActivityGovernorTakeWakeLeaseRequest<'static>>, ___E> for ActivityGovernorTakeWakeLeaseRequestwhere
___E: Encoder + ?Sized,
ActivityGovernorTakeWakeLeaseRequest: Encode<ActivityGovernorTakeWakeLeaseRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<ActivityGovernorTakeWakeLeaseRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ActivityGovernorTakeWakeLeaseRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<ActivityGovernorTakeWakeLeaseRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ActivityGovernorTakeWakeLeaseRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ActivityGovernorTakeWakeLeaseRequest<'de>> for ActivityGovernorTakeWakeLeaseRequest
impl<'de> FromWire<ActivityGovernorTakeWakeLeaseRequest<'de>> for ActivityGovernorTakeWakeLeaseRequest
Sourcefn from_wire(
wire: ActivityGovernorTakeWakeLeaseRequest<'de>,
) -> ActivityGovernorTakeWakeLeaseRequest
fn from_wire( wire: ActivityGovernorTakeWakeLeaseRequest<'de>, ) -> ActivityGovernorTakeWakeLeaseRequest
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ActivityGovernorTakeWakeLeaseRequest<'de>> for ActivityGovernorTakeWakeLeaseRequest
impl<'de> FromWireRef<ActivityGovernorTakeWakeLeaseRequest<'de>> for ActivityGovernorTakeWakeLeaseRequest
Sourcefn from_wire_ref(
wire: &ActivityGovernorTakeWakeLeaseRequest<'de>,
) -> ActivityGovernorTakeWakeLeaseRequest
fn from_wire_ref( wire: &ActivityGovernorTakeWakeLeaseRequest<'de>, ) -> ActivityGovernorTakeWakeLeaseRequest
Converts the given reference to this type.
Sourceimpl Ord for ActivityGovernorTakeWakeLeaseRequest
impl Ord for ActivityGovernorTakeWakeLeaseRequest
Sourcefn cmp(&self, other: &ActivityGovernorTakeWakeLeaseRequest) -> Ordering
fn cmp(&self, other: &ActivityGovernorTakeWakeLeaseRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ActivityGovernorTakeWakeLeaseRequest
impl PartialEq for ActivityGovernorTakeWakeLeaseRequest
Sourcefn eq(&self, other: &ActivityGovernorTakeWakeLeaseRequest) -> bool
fn eq(&self, other: &ActivityGovernorTakeWakeLeaseRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ActivityGovernorTakeWakeLeaseRequest
impl PartialOrd for ActivityGovernorTakeWakeLeaseRequest
impl Eq for ActivityGovernorTakeWakeLeaseRequest
impl StructuralPartialEq for ActivityGovernorTakeWakeLeaseRequest