#[repr(u8)]pub enum ApplicationActivityLevel {
Inactive = 0,
Active = 1,
UnknownOrdinal_(u8),
}Expand description
Application activity power levels
Elements that need to keep the system from suspending should take an assertive
dependency on ApplicationActivityLevel::ACTIVE. When these components are
performing work, they should request a lease to ensure the system remains
active, and drop the lease when they are done.
Variants