#[repr(C)]pub struct ActivityGovernorAcquireLongWakeLeaseResponse {
pub token: EventPair,
}Fields
token: EventPairTrait Implementations
Sourceimpl<___E> Encode<ActivityGovernorAcquireLongWakeLeaseResponse, ___E> for ActivityGovernorAcquireLongWakeLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ActivityGovernorAcquireLongWakeLeaseResponse, ___E> for ActivityGovernorAcquireLongWakeLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorAcquireLongWakeLeaseResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorAcquireLongWakeLeaseResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorAcquireLongWakeLeaseResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorAcquireLongWakeLeaseResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ActivityGovernorAcquireLongWakeLeaseResponse>, ___E> for ActivityGovernorAcquireLongWakeLeaseResponsewhere
___E: Encoder + ?Sized,
ActivityGovernorAcquireLongWakeLeaseResponse: Encode<ActivityGovernorAcquireLongWakeLeaseResponse, ___E>,
impl<___E> EncodeOption<Box<'static, ActivityGovernorAcquireLongWakeLeaseResponse>, ___E> for ActivityGovernorAcquireLongWakeLeaseResponsewhere
___E: Encoder + ?Sized,
ActivityGovernorAcquireLongWakeLeaseResponse: Encode<ActivityGovernorAcquireLongWakeLeaseResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ActivityGovernorAcquireLongWakeLeaseResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ActivityGovernorAcquireLongWakeLeaseResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ActivityGovernorAcquireLongWakeLeaseResponse> for ActivityGovernorAcquireLongWakeLeaseResponse
impl FromWire<ActivityGovernorAcquireLongWakeLeaseResponse> for ActivityGovernorAcquireLongWakeLeaseResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorAcquireLongWakeLeaseResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorAcquireLongWakeLeaseResponse, Self>
Sourcefn from_wire(wire: ActivityGovernorAcquireLongWakeLeaseResponse) -> Self
fn from_wire(wire: ActivityGovernorAcquireLongWakeLeaseResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for ActivityGovernorAcquireLongWakeLeaseResponse
impl PartialEq for ActivityGovernorAcquireLongWakeLeaseResponse
Sourcefn eq(&self, other: &ActivityGovernorAcquireLongWakeLeaseResponse) -> bool
fn eq(&self, other: &ActivityGovernorAcquireLongWakeLeaseResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ActivityGovernorAcquireLongWakeLeaseResponse