#[repr(C)]pub struct ActivityGovernorAcquireWakeLeaseResponse {
pub token: EventPair,
}Fields
token: EventPairTrait Implementations
Sourceimpl<___E> Encode<ActivityGovernorAcquireWakeLeaseResponse, ___E> for ActivityGovernorAcquireWakeLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ActivityGovernorAcquireWakeLeaseResponse, ___E> for ActivityGovernorAcquireWakeLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorAcquireWakeLeaseResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorAcquireWakeLeaseResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorAcquireWakeLeaseResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorAcquireWakeLeaseResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ActivityGovernorAcquireWakeLeaseResponse>, ___E> for ActivityGovernorAcquireWakeLeaseResponsewhere
___E: Encoder + ?Sized,
ActivityGovernorAcquireWakeLeaseResponse: Encode<ActivityGovernorAcquireWakeLeaseResponse, ___E>,
impl<___E> EncodeOption<Box<'static, ActivityGovernorAcquireWakeLeaseResponse>, ___E> for ActivityGovernorAcquireWakeLeaseResponsewhere
___E: Encoder + ?Sized,
ActivityGovernorAcquireWakeLeaseResponse: Encode<ActivityGovernorAcquireWakeLeaseResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ActivityGovernorAcquireWakeLeaseResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ActivityGovernorAcquireWakeLeaseResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ActivityGovernorAcquireWakeLeaseResponse> for ActivityGovernorAcquireWakeLeaseResponse
impl FromWire<ActivityGovernorAcquireWakeLeaseResponse> for ActivityGovernorAcquireWakeLeaseResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorAcquireWakeLeaseResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorAcquireWakeLeaseResponse, Self>
Sourcefn from_wire(wire: ActivityGovernorAcquireWakeLeaseResponse) -> Self
fn from_wire(wire: ActivityGovernorAcquireWakeLeaseResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for ActivityGovernorAcquireWakeLeaseResponse
impl PartialEq for ActivityGovernorAcquireWakeLeaseResponse
Sourcefn eq(&self, other: &ActivityGovernorAcquireWakeLeaseResponse) -> bool
fn eq(&self, other: &ActivityGovernorAcquireWakeLeaseResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ActivityGovernorAcquireWakeLeaseResponse