pub struct ActivityGovernorAcquireWakeLeaseWithTokenRequest {
pub name: String,
pub server_token: EventPair,
}Fields
name: Stringserver_token: EventPairTrait Implementations
Sourceimpl<___E> Encode<ActivityGovernorAcquireWakeLeaseWithTokenRequest<'static>, ___E> for ActivityGovernorAcquireWakeLeaseWithTokenRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<ActivityGovernorAcquireWakeLeaseWithTokenRequest<'static>, ___E> for ActivityGovernorAcquireWakeLeaseWithTokenRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorAcquireWakeLeaseWithTokenRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorAcquireWakeLeaseWithTokenRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, ActivityGovernorAcquireWakeLeaseWithTokenRequest<'static>>, ___E> for ActivityGovernorAcquireWakeLeaseWithTokenRequestwhere
___E: Encoder + ?Sized,
ActivityGovernorAcquireWakeLeaseWithTokenRequest: Encode<ActivityGovernorAcquireWakeLeaseWithTokenRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ActivityGovernorAcquireWakeLeaseWithTokenRequest<'static>>, ___E> for ActivityGovernorAcquireWakeLeaseWithTokenRequestwhere
___E: Encoder + ?Sized,
ActivityGovernorAcquireWakeLeaseWithTokenRequest: Encode<ActivityGovernorAcquireWakeLeaseWithTokenRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ActivityGovernorAcquireWakeLeaseWithTokenRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ActivityGovernorAcquireWakeLeaseWithTokenRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ActivityGovernorAcquireWakeLeaseWithTokenRequest<'de>> for ActivityGovernorAcquireWakeLeaseWithTokenRequest
impl<'de> FromWire<ActivityGovernorAcquireWakeLeaseWithTokenRequest<'de>> for ActivityGovernorAcquireWakeLeaseWithTokenRequest
Sourcefn from_wire(
wire: ActivityGovernorAcquireWakeLeaseWithTokenRequest<'de>,
) -> Self
fn from_wire( wire: ActivityGovernorAcquireWakeLeaseWithTokenRequest<'de>, ) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for ActivityGovernorAcquireWakeLeaseWithTokenRequest
impl PartialEq for ActivityGovernorAcquireWakeLeaseWithTokenRequest
Sourcefn eq(&self, other: &ActivityGovernorAcquireWakeLeaseWithTokenRequest) -> bool
fn eq(&self, other: &ActivityGovernorAcquireWakeLeaseWithTokenRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ActivityGovernorAcquireWakeLeaseWithTokenRequest