#[repr(C)]pub struct ActivityGovernorRegisterSuspendBlockerResponse {
pub token: EventPair,
}Fields
token: EventPairTrait Implementations
Sourceimpl<___E> Encode<ActivityGovernorRegisterSuspendBlockerResponse, ___E> for ActivityGovernorRegisterSuspendBlockerResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ActivityGovernorRegisterSuspendBlockerResponse, ___E> for ActivityGovernorRegisterSuspendBlockerResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorRegisterSuspendBlockerResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorRegisterSuspendBlockerResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorRegisterSuspendBlockerResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorRegisterSuspendBlockerResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ActivityGovernorRegisterSuspendBlockerResponse>, ___E> for ActivityGovernorRegisterSuspendBlockerResponsewhere
___E: Encoder + ?Sized,
ActivityGovernorRegisterSuspendBlockerResponse: Encode<ActivityGovernorRegisterSuspendBlockerResponse, ___E>,
impl<___E> EncodeOption<Box<'static, ActivityGovernorRegisterSuspendBlockerResponse>, ___E> for ActivityGovernorRegisterSuspendBlockerResponsewhere
___E: Encoder + ?Sized,
ActivityGovernorRegisterSuspendBlockerResponse: Encode<ActivityGovernorRegisterSuspendBlockerResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ActivityGovernorRegisterSuspendBlockerResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ActivityGovernorRegisterSuspendBlockerResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ActivityGovernorRegisterSuspendBlockerResponse> for ActivityGovernorRegisterSuspendBlockerResponse
impl FromWire<ActivityGovernorRegisterSuspendBlockerResponse> for ActivityGovernorRegisterSuspendBlockerResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorRegisterSuspendBlockerResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorRegisterSuspendBlockerResponse, Self>
Sourcefn from_wire(wire: ActivityGovernorRegisterSuspendBlockerResponse) -> Self
fn from_wire(wire: ActivityGovernorRegisterSuspendBlockerResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for ActivityGovernorRegisterSuspendBlockerResponse
impl PartialEq for ActivityGovernorRegisterSuspendBlockerResponse
Sourcefn eq(&self, other: &ActivityGovernorRegisterSuspendBlockerResponse) -> bool
fn eq(&self, other: &ActivityGovernorRegisterSuspendBlockerResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ActivityGovernorRegisterSuspendBlockerResponse