#[repr(C)]pub struct ActivityGovernorTakeApplicationActivityLeaseResponse {
pub token: EventPair,
}Fields
token: EventPairTrait Implementations
Sourceimpl<___E> Encode<ActivityGovernorTakeApplicationActivityLeaseResponse, ___E> for ActivityGovernorTakeApplicationActivityLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ActivityGovernorTakeApplicationActivityLeaseResponse, ___E> for ActivityGovernorTakeApplicationActivityLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorTakeApplicationActivityLeaseResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorTakeApplicationActivityLeaseResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorTakeApplicationActivityLeaseResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorTakeApplicationActivityLeaseResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ActivityGovernorTakeApplicationActivityLeaseResponse>, ___E> for ActivityGovernorTakeApplicationActivityLeaseResponsewhere
___E: Encoder + ?Sized,
ActivityGovernorTakeApplicationActivityLeaseResponse: Encode<ActivityGovernorTakeApplicationActivityLeaseResponse, ___E>,
impl<___E> EncodeOption<Box<'static, ActivityGovernorTakeApplicationActivityLeaseResponse>, ___E> for ActivityGovernorTakeApplicationActivityLeaseResponsewhere
___E: Encoder + ?Sized,
ActivityGovernorTakeApplicationActivityLeaseResponse: Encode<ActivityGovernorTakeApplicationActivityLeaseResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ActivityGovernorTakeApplicationActivityLeaseResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ActivityGovernorTakeApplicationActivityLeaseResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ActivityGovernorTakeApplicationActivityLeaseResponse> for ActivityGovernorTakeApplicationActivityLeaseResponse
impl FromWire<ActivityGovernorTakeApplicationActivityLeaseResponse> for ActivityGovernorTakeApplicationActivityLeaseResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorTakeApplicationActivityLeaseResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorTakeApplicationActivityLeaseResponse, Self>
Sourcefn from_wire(wire: ActivityGovernorTakeApplicationActivityLeaseResponse) -> Self
fn from_wire(wire: ActivityGovernorTakeApplicationActivityLeaseResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for ActivityGovernorTakeApplicationActivityLeaseResponse
impl PartialEq for ActivityGovernorTakeApplicationActivityLeaseResponse
Sourcefn eq(
&self,
other: &ActivityGovernorTakeApplicationActivityLeaseResponse,
) -> bool
fn eq( &self, other: &ActivityGovernorTakeApplicationActivityLeaseResponse, ) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ActivityGovernorTakeApplicationActivityLeaseResponse