#[repr(C)]pub struct ActivityGovernorTakeWakeLeaseResponse {
pub token: EventPair,
}Fields
token: EventPairTrait Implementations
Sourceimpl<___E> Encode<ActivityGovernorTakeWakeLeaseResponse, ___E> for ActivityGovernorTakeWakeLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ActivityGovernorTakeWakeLeaseResponse, ___E> for ActivityGovernorTakeWakeLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorTakeWakeLeaseResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorTakeWakeLeaseResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorTakeWakeLeaseResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorTakeWakeLeaseResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ActivityGovernorTakeWakeLeaseResponse>, ___E> for ActivityGovernorTakeWakeLeaseResponsewhere
___E: Encoder + ?Sized,
ActivityGovernorTakeWakeLeaseResponse: Encode<ActivityGovernorTakeWakeLeaseResponse, ___E>,
impl<___E> EncodeOption<Box<'static, ActivityGovernorTakeWakeLeaseResponse>, ___E> for ActivityGovernorTakeWakeLeaseResponsewhere
___E: Encoder + ?Sized,
ActivityGovernorTakeWakeLeaseResponse: Encode<ActivityGovernorTakeWakeLeaseResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ActivityGovernorTakeWakeLeaseResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ActivityGovernorTakeWakeLeaseResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ActivityGovernorTakeWakeLeaseResponse> for ActivityGovernorTakeWakeLeaseResponse
impl FromWire<ActivityGovernorTakeWakeLeaseResponse> for ActivityGovernorTakeWakeLeaseResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorTakeWakeLeaseResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorTakeWakeLeaseResponse, Self>
Sourcefn from_wire(wire: ActivityGovernorTakeWakeLeaseResponse) -> Self
fn from_wire(wire: ActivityGovernorTakeWakeLeaseResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for ActivityGovernorTakeWakeLeaseResponse
impl PartialEq for ActivityGovernorTakeWakeLeaseResponse
Sourcefn eq(&self, other: &ActivityGovernorTakeWakeLeaseResponse) -> bool
fn eq(&self, other: &ActivityGovernorTakeWakeLeaseResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ActivityGovernorTakeWakeLeaseResponse