pub struct ExecutionState {
pub dependency_token: Option<Event>,
}Expand description
Holds the dependency token for the Execution State power element.
Fields
dependency_token: Option<Event>Trait Implementations
Sourceimpl Debug for ExecutionState
impl Debug for ExecutionState
Sourceimpl Default for ExecutionState
impl Default for ExecutionState
Sourcefn default() -> ExecutionState
fn default() -> ExecutionState
Returns the “default value” for a type. Read more
Sourceimpl<___E> Encode<ExecutionState<'static>, ___E> for ExecutionStatewhere
___E: Encoder + ?Sized + HandleEncoder,
impl<___E> Encode<ExecutionState<'static>, ___E> for ExecutionStatewhere
___E: Encoder + ?Sized + HandleEncoder,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<ExecutionState<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<ExecutionState<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<ExecutionState<'de>> for ExecutionState
impl<'de> FromWire<ExecutionState<'de>> for ExecutionState
Sourcefn from_wire(wire_: ExecutionState<'de>) -> Self
fn from_wire(wire_: ExecutionState<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for ExecutionState
impl PartialEq for ExecutionState
Sourcefn eq(&self, other: &ExecutionState) -> bool
fn eq(&self, other: &ExecutionState) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExecutionState