BootControlLocalServerHandler

Trait BootControlLocalServerHandler 

pub trait BootControlLocalServerHandler<___T = Channel>
where ___T: Transport,
{ // Required method fn set_boot_complete( &mut self, responder: Responder<SetBootComplete, ___T>, ) -> impl Future<Output = ()>; // Provided method fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> { ... } }
A server handler for the BootControl protocol.

See BootControl for more details.

Required Methods

fn set_boot_complete( &mut self, responder: Responder<SetBootComplete, ___T>, ) -> impl Future<Output = ()>

Notify the SAG that the system has booted. SAG will not suspend the hardware platform until this method is called at least once per boot.

Provided Methods

fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> BootControlLocalServerHandler<___T> for Local<___H>
where ___H: BootControlServerHandler<___T>, ___T: Transport,

Source

async fn set_boot_complete( &mut self, responder: Responder<SetBootComplete, ___T>, )

Source

async fn on_unknown_interaction(&mut self, ordinal: u64)

Implementors