#[repr(C)]pub struct ActivityGovernorAcquireLongWakeLeaseResponse {
pub token: EventPair,
}Expand description
The wire type corresponding to ActivityGovernorAcquireLongWakeLeaseResponse.
Fields
token: EventPairTrait Implementations
Sourceimpl Constrained for ActivityGovernorAcquireLongWakeLeaseResponse
impl Constrained for ActivityGovernorAcquireLongWakeLeaseResponse
Sourceimpl<___D> Decode<___D> for ActivityGovernorAcquireLongWakeLeaseResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ActivityGovernorAcquireLongWakeLeaseResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ActivityGovernorAcquireLongWakeLeaseResponse, ___E> for ActivityGovernorAcquireLongWakeLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ActivityGovernorAcquireLongWakeLeaseResponse, ___E> for ActivityGovernorAcquireLongWakeLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorAcquireLongWakeLeaseResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorAcquireLongWakeLeaseResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorAcquireLongWakeLeaseResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorAcquireLongWakeLeaseResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ActivityGovernorAcquireLongWakeLeaseResponse, ___E> for ActivityGovernorAcquireLongWakeLeaseResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<EventPair, ___E>,
impl<___E, T0> Encode<ActivityGovernorAcquireLongWakeLeaseResponse, ___E> for ActivityGovernorAcquireLongWakeLeaseResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<EventPair, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorAcquireLongWakeLeaseResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorAcquireLongWakeLeaseResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ActivityGovernorAcquireLongWakeLeaseResponse> for ActivityGovernorAcquireLongWakeLeaseResponse
impl FromWire<ActivityGovernorAcquireLongWakeLeaseResponse> for ActivityGovernorAcquireLongWakeLeaseResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorAcquireLongWakeLeaseResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorAcquireLongWakeLeaseResponse, Self>
Sourcefn from_wire(wire: ActivityGovernorAcquireLongWakeLeaseResponse) -> Self
fn from_wire(wire: ActivityGovernorAcquireLongWakeLeaseResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ActivityGovernorAcquireLongWakeLeaseResponse
impl IntoNatural for ActivityGovernorAcquireLongWakeLeaseResponse
Sourcetype Natural = ActivityGovernorAcquireLongWakeLeaseResponse
type Natural = ActivityGovernorAcquireLongWakeLeaseResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ActivityGovernorAcquireLongWakeLeaseResponse
impl Wire for ActivityGovernorAcquireLongWakeLeaseResponse
Sourcetype Narrowed<'de> = ActivityGovernorAcquireLongWakeLeaseResponse
type Narrowed<'de> = ActivityGovernorAcquireLongWakeLeaseResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.