#[repr(C)]pub struct ActivityGovernorAcquireWakeLeaseResponse {
pub token: EventPair,
}Expand description
The wire type corresponding to ActivityGovernorAcquireWakeLeaseResponse.
Fields
token: EventPairTrait Implementations
Sourceimpl Constrained for ActivityGovernorAcquireWakeLeaseResponse
impl Constrained for ActivityGovernorAcquireWakeLeaseResponse
Sourceimpl<___D> Decode<___D> for ActivityGovernorAcquireWakeLeaseResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ActivityGovernorAcquireWakeLeaseResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ActivityGovernorAcquireWakeLeaseResponse, ___E> for ActivityGovernorAcquireWakeLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ActivityGovernorAcquireWakeLeaseResponse, ___E> for ActivityGovernorAcquireWakeLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorAcquireWakeLeaseResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorAcquireWakeLeaseResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorAcquireWakeLeaseResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorAcquireWakeLeaseResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ActivityGovernorAcquireWakeLeaseResponse, ___E> for ActivityGovernorAcquireWakeLeaseResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<EventPair, ___E>,
impl<___E, T0> Encode<ActivityGovernorAcquireWakeLeaseResponse, ___E> for ActivityGovernorAcquireWakeLeaseResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<EventPair, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorAcquireWakeLeaseResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorAcquireWakeLeaseResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ActivityGovernorAcquireWakeLeaseResponse> for ActivityGovernorAcquireWakeLeaseResponse
impl FromWire<ActivityGovernorAcquireWakeLeaseResponse> for ActivityGovernorAcquireWakeLeaseResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorAcquireWakeLeaseResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorAcquireWakeLeaseResponse, Self>
Sourcefn from_wire(wire: ActivityGovernorAcquireWakeLeaseResponse) -> Self
fn from_wire(wire: ActivityGovernorAcquireWakeLeaseResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ActivityGovernorAcquireWakeLeaseResponse
impl IntoNatural for ActivityGovernorAcquireWakeLeaseResponse
Sourcetype Natural = ActivityGovernorAcquireWakeLeaseResponse
type Natural = ActivityGovernorAcquireWakeLeaseResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ActivityGovernorAcquireWakeLeaseResponse
impl Wire for ActivityGovernorAcquireWakeLeaseResponse
Sourcetype Narrowed<'de> = ActivityGovernorAcquireWakeLeaseResponse
type Narrowed<'de> = ActivityGovernorAcquireWakeLeaseResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.