#[repr(C)]pub struct ActivityGovernorRegisterSuspendBlockerResponse {
pub token: EventPair,
}Expand description
The wire type corresponding to ActivityGovernorRegisterSuspendBlockerResponse.
Fields
token: EventPairTrait Implementations
Sourceimpl Constrained for ActivityGovernorRegisterSuspendBlockerResponse
impl Constrained for ActivityGovernorRegisterSuspendBlockerResponse
Sourceimpl<___D> Decode<___D> for ActivityGovernorRegisterSuspendBlockerResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ActivityGovernorRegisterSuspendBlockerResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ActivityGovernorRegisterSuspendBlockerResponse, ___E> for ActivityGovernorRegisterSuspendBlockerResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ActivityGovernorRegisterSuspendBlockerResponse, ___E> for ActivityGovernorRegisterSuspendBlockerResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorRegisterSuspendBlockerResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorRegisterSuspendBlockerResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorRegisterSuspendBlockerResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorRegisterSuspendBlockerResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ActivityGovernorRegisterSuspendBlockerResponse, ___E> for ActivityGovernorRegisterSuspendBlockerResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<EventPair, ___E>,
impl<___E, T0> Encode<ActivityGovernorRegisterSuspendBlockerResponse, ___E> for ActivityGovernorRegisterSuspendBlockerResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<EventPair, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorRegisterSuspendBlockerResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorRegisterSuspendBlockerResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ActivityGovernorRegisterSuspendBlockerResponse> for ActivityGovernorRegisterSuspendBlockerResponse
impl FromWire<ActivityGovernorRegisterSuspendBlockerResponse> for ActivityGovernorRegisterSuspendBlockerResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorRegisterSuspendBlockerResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorRegisterSuspendBlockerResponse, Self>
Sourcefn from_wire(wire: ActivityGovernorRegisterSuspendBlockerResponse) -> Self
fn from_wire(wire: ActivityGovernorRegisterSuspendBlockerResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ActivityGovernorRegisterSuspendBlockerResponse
impl IntoNatural for ActivityGovernorRegisterSuspendBlockerResponse
Sourcetype Natural = ActivityGovernorRegisterSuspendBlockerResponse
type Natural = ActivityGovernorRegisterSuspendBlockerResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ActivityGovernorRegisterSuspendBlockerResponse
impl Wire for ActivityGovernorRegisterSuspendBlockerResponse
Sourcetype Narrowed<'de> = ActivityGovernorRegisterSuspendBlockerResponse
type Narrowed<'de> = ActivityGovernorRegisterSuspendBlockerResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.