#[repr(C)]pub struct ActivityGovernorTakeApplicationActivityLeaseResponse {
pub token: EventPair,
}Expand description
The wire type corresponding to ActivityGovernorTakeApplicationActivityLeaseResponse.
Fields
token: EventPairTrait Implementations
Sourceimpl Constrained for ActivityGovernorTakeApplicationActivityLeaseResponse
impl Constrained for ActivityGovernorTakeApplicationActivityLeaseResponse
Sourceimpl<___D> Decode<___D> for ActivityGovernorTakeApplicationActivityLeaseResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ActivityGovernorTakeApplicationActivityLeaseResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ActivityGovernorTakeApplicationActivityLeaseResponse, ___E> for ActivityGovernorTakeApplicationActivityLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ActivityGovernorTakeApplicationActivityLeaseResponse, ___E> for ActivityGovernorTakeApplicationActivityLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorTakeApplicationActivityLeaseResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorTakeApplicationActivityLeaseResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorTakeApplicationActivityLeaseResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorTakeApplicationActivityLeaseResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ActivityGovernorTakeApplicationActivityLeaseResponse, ___E> for ActivityGovernorTakeApplicationActivityLeaseResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<EventPair, ___E>,
impl<___E, T0> Encode<ActivityGovernorTakeApplicationActivityLeaseResponse, ___E> for ActivityGovernorTakeApplicationActivityLeaseResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<EventPair, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorTakeApplicationActivityLeaseResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorTakeApplicationActivityLeaseResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ActivityGovernorTakeApplicationActivityLeaseResponse> for ActivityGovernorTakeApplicationActivityLeaseResponse
impl FromWire<ActivityGovernorTakeApplicationActivityLeaseResponse> for ActivityGovernorTakeApplicationActivityLeaseResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorTakeApplicationActivityLeaseResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorTakeApplicationActivityLeaseResponse, Self>
Sourcefn from_wire(wire: ActivityGovernorTakeApplicationActivityLeaseResponse) -> Self
fn from_wire(wire: ActivityGovernorTakeApplicationActivityLeaseResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ActivityGovernorTakeApplicationActivityLeaseResponse
impl IntoNatural for ActivityGovernorTakeApplicationActivityLeaseResponse
Sourcetype Natural = ActivityGovernorTakeApplicationActivityLeaseResponse
type Natural = ActivityGovernorTakeApplicationActivityLeaseResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ActivityGovernorTakeApplicationActivityLeaseResponse
impl Wire for ActivityGovernorTakeApplicationActivityLeaseResponse
Sourcetype Narrowed<'de> = ActivityGovernorTakeApplicationActivityLeaseResponse
type Narrowed<'de> = ActivityGovernorTakeApplicationActivityLeaseResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.