#[repr(C)]pub struct ActivityGovernorTakeWakeLeaseResponse {
pub token: EventPair,
}Expand description
The wire type corresponding to ActivityGovernorTakeWakeLeaseResponse.
Fields
token: EventPairTrait Implementations
Sourceimpl Constrained for ActivityGovernorTakeWakeLeaseResponse
impl Constrained for ActivityGovernorTakeWakeLeaseResponse
Sourceimpl<___D> Decode<___D> for ActivityGovernorTakeWakeLeaseResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ActivityGovernorTakeWakeLeaseResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ActivityGovernorTakeWakeLeaseResponse, ___E> for ActivityGovernorTakeWakeLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ActivityGovernorTakeWakeLeaseResponse, ___E> for ActivityGovernorTakeWakeLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorTakeWakeLeaseResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ActivityGovernorTakeWakeLeaseResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorTakeWakeLeaseResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorTakeWakeLeaseResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ActivityGovernorTakeWakeLeaseResponse, ___E> for ActivityGovernorTakeWakeLeaseResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<EventPair, ___E>,
impl<___E, T0> Encode<ActivityGovernorTakeWakeLeaseResponse, ___E> for ActivityGovernorTakeWakeLeaseResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<EventPair, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorTakeWakeLeaseResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorTakeWakeLeaseResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ActivityGovernorTakeWakeLeaseResponse> for ActivityGovernorTakeWakeLeaseResponse
impl FromWire<ActivityGovernorTakeWakeLeaseResponse> for ActivityGovernorTakeWakeLeaseResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorTakeWakeLeaseResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ActivityGovernorTakeWakeLeaseResponse, Self>
Sourcefn from_wire(wire: ActivityGovernorTakeWakeLeaseResponse) -> Self
fn from_wire(wire: ActivityGovernorTakeWakeLeaseResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ActivityGovernorTakeWakeLeaseResponse
impl IntoNatural for ActivityGovernorTakeWakeLeaseResponse
Sourcetype Natural = ActivityGovernorTakeWakeLeaseResponse
type Natural = ActivityGovernorTakeWakeLeaseResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ActivityGovernorTakeWakeLeaseResponse
impl Wire for ActivityGovernorTakeWakeLeaseResponse
Sourcetype Narrowed<'de> = ActivityGovernorTakeWakeLeaseResponse
type Narrowed<'de> = ActivityGovernorTakeWakeLeaseResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.