pub trait ExecutionStateManagerLocalServerHandler<___T: Transport = Channel> {
// Required methods
fn get_execution_state_dependency_token(
&mut self,
responder: Responder<GetExecutionStateDependencyToken, ___T>,
) -> impl Future<Output = ()>;
fn add_application_activity_dependency(
&mut self,
request: Request<AddApplicationActivityDependency, ___T>,
responder: Responder<AddApplicationActivityDependency, ___T>,
) -> impl Future<Output = ()>;
// Provided method
fn on_unknown_interaction(
&mut self,
ordinal: u64,
) -> impl Future<Output = ()> { ... }
}Expand description
A server handler for the ExecutionStateManager protocol.
See ExecutionStateManager for more details.
Required Methods
Sourcefn get_execution_state_dependency_token(
&mut self,
responder: Responder<GetExecutionStateDependencyToken, ___T>,
) -> impl Future<Output = ()>
fn get_execution_state_dependency_token( &mut self, responder: Responder<GetExecutionStateDependencyToken, ___T>, ) -> impl Future<Output = ()>
Gets the dependency token for the execution state power element. This will block if SAG is not fully initialized.
Sourcefn add_application_activity_dependency(
&mut self,
request: Request<AddApplicationActivityDependency, ___T>,
responder: Responder<AddApplicationActivityDependency, ___T>,
) -> impl Future<Output = ()>
fn add_application_activity_dependency( &mut self, request: Request<AddApplicationActivityDependency, ___T>, responder: Responder<AddApplicationActivityDependency, ___T>, ) -> impl Future<Output = ()>
Adds a dependency from the Application Activity power element to the target
power element identified by [dependency_token] at [power_level].
Be aware of the following client-side conditions:
- If SAG is not fully initialized, the call blocks until initialization is complete.
- The call may block as required by
fuchsia.power.broker/ElementControl.AddDependency, which at time of writing may callfuchsia.power.ElementControl.SetLevelon the associated power element.
Provided Methods
fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.